@@ -157,6 +157,11 @@ class CPCPeakHandler:
             "%Y-%m-%dT%H:%M:%S.%f%z",
         )
 
+    @property
+    def is_winter(self) -> bool:
+        """Return true if we are in winter period."""
+        return self.winter_start_date >= utils.now() >= self.winter_end_date
+
     @property
     def cumulated_credit(self) -> float:
         """Get cumulated credits."""
@@ -201,7 +206,7 @@ class CPCPeakHandler:
         current_date = self.winter_start_date
         delta = datetime.timedelta(days=1)
         peak_list: list[Peak] = []
-        while current_date < self.winter_end_date:
+        while current_date.date() <= self.winter_end_date.date():
             # Morning
             peak = Peak(
                 current_date, "morning", preheat_duration=self._preheat_duration
